==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/healthcareapis/kotlin/inputs/CorsConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.healthcareapis.kotlin.inputs

import com.pulumi.azurenative.healthcareapis.inputs.CorsConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The settings for the CORS configuration of the service instance.
 * @property allowCredentials If credentials are allowed via CORS.
 * @property headers The headers to be allowed via CORS.
 * @property maxAge The max age to be allowed via CORS.
 * @property methods The methods to be allowed via CORS.
 * @property origins The origins to be allowed via CORS.
 */
public data class CorsConfigurationArgs(
    public val allowCredentials: Output<Boolean>? = null,
    public val headers: Output<List<String>>? = null,
    public val maxAge: Output<Int>? = null,
    public val methods: Output<List<String>>? = null,
    public val origins: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.healthcareapis.inputs.CorsConfigurationArgs> {
    override fun toJava(): com.pulumi.azurenative.healthcareapis.inputs.CorsConfigurationArgs =
        com.pulumi.azurenative.healthcareapis.inputs.CorsConfigurationArgs.builder()
            .allowCredentials(allowCredentials?.applyValue({ args0 -> args0 }))
            .headers(headers?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .maxAge(maxAge?.applyValue({ args0 -> args0 }))
            .methods(methods?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .origins(origins?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [CorsConfigurationArgs].
 */
@PulumiTagMarker
public class CorsConfigurationArgsBuilder internal constructor() {
    private var allowCredentials: Output<Boolean>? = null

    private var headers: Output<List<String>>? = null

    private var maxAge: Output<Int>? = null

    private var methods: Output<List<String>>? = null

    private var origins: Output<List<String>>? = null

    /**
     * @param value If credentials are allowed via CORS.
     */
    @JvmName("sglvoaeluecbtfrd")
    public suspend fun allowCredentials(`value`: Output<Boolean>) {
        this.allowCredentials = value
    }

    /**
     * @param value The headers to be allowed via CORS.
     */
    @JvmName("odnwddnllwlpgnkf")
    public suspend fun headers(`value`: Output<List<String>>) {
        this.headers = value
    }

    @JvmName("gimlslfbnqkunexp")
    public suspend fun headers(vararg values: Output<String>) {
        this.headers = Output.all(values.asList())
    }

    /**
     * @param values The headers to be allowed via CORS.
     */
    @JvmName("nleitheqcnprfdmh")
    public suspend fun headers(values: List<Output<String>>) {
        this.headers = Output.all(values)
    }

    /**
     * @param value The max age to be allowed via CORS.
     */
    @JvmName("axouaohfqotopbnr")
    public suspend fun maxAge(`value`: Output<Int>) {
        this.maxAge = value
    }

    /**
     * @param value The methods to be allowed via CORS.
     */
    @JvmName("ixykrsshfjqwtcvx")
    public suspend fun methods(`value`: Output<List<String>>) {
        this.methods = value
    }

    @JvmName("nqdgnrrdlolweowe")
    public suspend fun methods(vararg values: Output<String>) {
        this.methods = Output.all(values.asList())
    }

    /**
     * @param values The methods to be allowed via CORS.
     */
    @JvmName("bkqfiqjefdrhvneu")
    public suspend fun methods(values: List<Output<String>>) {
        this.methods = Output.all(values)
    }

    /**
     * @param value The origins to be allowed via CORS.
     */
    @JvmName("txkmeeeobmtkxaiy")
    public suspend fun origins(`value`: Output<List<String>>) {
        this.origins = value
    }

    @JvmName("rgcygmcgvsimdili")
    public suspend fun origins(vararg values: Output<String>) {
        this.origins = Output.all(values.asList())
    }

    /**
     * @param values The origins to be allowed via CORS.
     */
    @JvmName("btexfuxhfqdapxvc")
    public suspend fun origins(values: List<Output<String>>) {
        this.origins = Output.all(values)
    }

    /**
     * @param value If credentials are allowed via CORS.
     */
    @JvmName("ecsafphqkquuahdy")
    public suspend fun allowCredentials(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.allowCredentials = mapped
    }

    /**
     * @param value The headers to be allowed via CORS.
     */
    @JvmName("kqvqwrwrswsmtvkt")
    public suspend fun headers(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.headers = mapped
    }

    /**
     * @param values The headers to be allowed via CORS.
     */
    @JvmName("hpubnuyoheoatckg")
    public suspend fun headers(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.headers = mapped
    }

    /**
     * @param value The max age to be allowed via CORS.
     */
    @JvmName("vfrcfqrbfuvpfslu")
    public suspend fun maxAge(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.maxAge = mapped
    }

    /**
     * @param value The methods to be allowed via CORS.
     */
    @JvmName("hhlykghjrvihvqgg")
    public suspend fun methods(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.methods = mapped
    }

    /**
     * @param values The methods to be allowed via CORS.
     */
    @JvmName("wuwfieixbuafcvuc")
    public suspend fun methods(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.methods = mapped
    }

    /**
     * @param value The origins to be allowed via CORS.
     */
    @JvmName("bqbigfwyxdstqmrb")
    public suspend fun origins(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.origins = mapped
    }

    /**
     * @param values The origins to be allowed via CORS.
     */
    @JvmName("sisqxwcotiwnkdfe")
    public suspend fun origins(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.origins = mapped
    }

    internal fun build(): CorsConfigurationArgs = CorsConfigurationArgs(
        allowCredentials = allowCredentials,
        headers = headers,
        maxAge = maxAge,
        methods = methods,
        origins = origins,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/healthcareapis/kotlin/inputs/CorsConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.healthcareapis.kotlin.inputs

import com.pulumi.azurenative.healthcareapis.inputs.CorsConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The settings for the CORS configuration of the service instance.
 * @property allowCredentials If credentials are allowed via CORS.
 * @property headers The headers to be allowed via CORS.
 * @property maxAge The max age to be allowed via CORS.
 * @property methods The methods to be allowed via CORS.
 * @property origins The origins to be allowed via CORS.
 */
public data class CorsConfigurationArgs(
    public val allowCredentials: Output<Boolean>? = null,
    public val headers: Output<List<String>>? = null,
    public val maxAge: Output<Int>? = null,
    public val methods: Output<List<String>>? = null,
    public val origins: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.healthcareapis.inputs.CorsConfigurationArgs> {
    override fun toJava(): com.pulumi.azurenative.healthcareapis.inputs.CorsConfigurationArgs =
        com.pulumi.azurenative.healthcareapis.inputs.CorsConfigurationArgs.builder()
            .allowCredentials(allowCredentials?.applyValue({ args0 -> args0 }))
            .headers(headers?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .maxAge(maxAge?.applyValue({ args0 -> args0 }))
            .methods(methods?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .origins(origins?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [CorsConfigurationArgs].
 */
@PulumiTagMarker
public class CorsConfigurationArgsBuilder internal constructor() {
    private var allowCredentials: Output<Boolean>? = null

    private var headers: Output<List<String>>? = null

    private var maxAge: Output<Int>? = null

    private var methods: Output<List<String>>? = null

    private var origins: Output<List<String>>? = null

    /**
     * @param value If credentials are allowed via CORS.
     */
    @JvmName("bgydpvdborwpcsqq")
    public suspend fun allowCredentials(`value`: Output<Boolean>) {
        this.allowCredentials = value
    }

    /**
     * @param value The headers to be allowed via CORS.
     */
    @JvmName("jkofqbafxjgjyvik")
    public suspend fun headers(`value`: Output<List<String>>) {
        this.headers = value
    }

    @JvmName("jwfstknugaalxvqp")
    public suspend fun headers(vararg values: Output<String>) {
        this.headers = Output.all(values.asList())
    }

    /**
     * @param values The headers to be allowed via CORS.
     */
    @JvmName("ynhiivmdorpnwnor")
    public suspend fun headers(values: List<Output<String>>) {
        this.headers = Output.all(values)
    }

    /**
     * @param value The max age to be allowed via CORS.
     */
    @JvmName("hifbaskqnskfqduu")
    public suspend fun maxAge(`value`: Output<Int>) {
        this.maxAge = value
    }

    /**
     * @param value The methods to be allowed via CORS.
     */
    @JvmName("wxnuwsxyiebljasn")
    public suspend fun methods(`value`: Output<List<String>>) {
        this.methods = value
    }

    @JvmName("xguaxfyrmuchqycv")
    public suspend fun methods(vararg values: Output<String>) {
        this.methods = Output.all(values.asList())
    }

    /**
     * @param values The methods to be allowed via CORS.
     */
    @JvmName("ugeitmfbtlecpuaq")
    public suspend fun methods(values: List<Output<String>>) {
        this.methods = Output.all(values)
    }

    /**
     * @param value The origins to be allowed via CORS.
     */
    @JvmName("yrqxejrskcbleptk")
    public suspend fun origins(`value`: Output<List<String>>) {
        this.origins = value
    }

    @JvmName("cwspkrnlmnatgtuc")
    public suspend fun origins(vararg values: Output<String>) {
        this.origins = Output.all(values.asList())
    }

    /**
     * @param values The origins to be allowed via CORS.
     */
    @JvmName("iulabomcbcthpqia")
    public suspend fun origins(values: List<Output<String>>) {
        this.origins = Output.all(values)
    }

    /**
     * @param value If credentials are allowed via CORS.
     */
    @JvmName("bciuxhablktwrefc")
    public suspend fun allowCredentials(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.allowCredentials = mapped
    }

    /**
     * @param value The headers to be allowed via CORS.
     */
    @JvmName("qeuruiahskqwbmkw")
    public suspend fun headers(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.headers = mapped
    }

    /**
     * @param values The headers to be allowed via CORS.
     */
    @JvmName("dtuvillbudqhpqcc")
    public suspend fun headers(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.headers = mapped
    }

    /**
     * @param value The max age to be allowed via CORS.
     */
    @JvmName("nfqhcssppfrwxbvn")
    public suspend fun maxAge(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.maxAge = mapped
    }

    /**
     * @param value The methods to be allowed via CORS.
     */
    @JvmName("gxwbwquslrutlhbu")
    public suspend fun methods(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.methods = mapped
    }

    /**
     * @param values The methods to be allowed via CORS.
     */
    @JvmName("auedughjvbesfeht")
    public suspend fun methods(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.methods = mapped
    }

    /**
     * @param value The origins to be allowed via CORS.
     */
    @JvmName("rbkwoiciaqjopyss")
    public suspend fun origins(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.origins = mapped
    }

    /**
     * @param values The origins to be allowed via CORS.
     */
    @JvmName("cjtldoukvrdhplte")
    public suspend fun origins(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.origins = mapped
    }

    internal fun build(): CorsConfigurationArgs = CorsConfigurationArgs(
        allowCredentials = allowCredentials,
        headers = headers,
        maxAge = maxAge,
        methods = methods,
        origins = origins,
    )
}
